-- Create a 7x1 image for a hue gradient as an example of an image to cut
local bg = love.graphics.newImage(love.image.newImageData(7, 1, "rgba8",
     "\255\000\000\255" -- Red
  .. "\255\255\000\255" -- Yellow
  .. "\000\255\000\255" -- Green
  .. "\000\255\255\255" -- Cyan
  .. "\000\000\255\255" -- Blue
  .. "\255\000\255\255" -- Magenta
  .. "\255\000\000\255" -- Red
))
-- Load a mask from disk
local mask = love.graphics.newImage('publicdomainq-perplexed-reduced-mask.png')

local canvas = love.graphics.newCanvas()

love.graphics.setBackgroundColor(0.5, 0.5, 0.5)

function love.draw()
  -- Draw to the canvas to do the masking
  love.graphics.setCanvas(canvas)

  -- The canvas needs to be initialized to transparent black for this to work
  love.graphics.clear(0, 0, 0, 0)

  -- Draw a hue gradient as background, stretched to 180x180
  love.graphics.draw(bg, 400, 450, 0, 180/7, 180/1, 7/2, 1/2)

  -- Do the masking here
  love.graphics.setBlendMode("multiply", "premultiplied")
  love.graphics.draw(mask, 400, 450, 0, 1, 1, mask:getWidth()/2, mask:getHeight()/2)
  -- Disable drawing to the canvas
  love.graphics.setCanvas()

  -- Draw the canvas to the screen
  -- With rare exceptions, canvases need to be drawn in premultiplied mode
  love.graphics.setBlendMode("alpha", "premultiplied")
  love.graphics.draw(canvas)

  -- Draw the mask in replace mode so that you can see the pixels (because the
  -- alpha will be ignored by the screen)
  love.graphics.setBlendMode("replace", "premultiplied")
  love.graphics.draw(mask, 500, 100)

  -- Restore normal blend mode
  love.graphics.setBlendMode("alpha", "alphamultiply")
  -- Draw the background
  love.graphics.draw(bg, 150, 100, 0, 180/7, 180/1)
end
